% Shrub Mangroves Facilitate Self-Sustaining Conditions for Colonization: Insights from the Nanliu Delta, China
% by Xiaoyan Zhou
% version: 20250107

clc;
clear;

%% --- Data Import ---
TAB_Hydro = readtable('Hydrodynamic.xlsx', 'VariableNamingRule', 'preserve');
TAB_Veg = readtable('VegetationInfo.xlsx', 'VariableNamingRule', 'preserve');

%% --- Figure 2 ---
figure 
tiledlayout(1,2)

nexttile
% SM classification
SV=TAB_Veg.("BottomArea(m2)");
binWidth = 0.08;
lastVal = ceil(max(SV));
binEdges = 0:binWidth:lastVal+1;
yyaxis left
h = histogram(SV,binEdges);
xlim([0 1]);
ylim([0 10]);
hold on
counts = histcounts(SV,binEdges);
binCtrs = binEdges(1:end-1) + binWidth/2;
h.FaceColor = [.9 .9 .9];
hold on
plot(binCtrs,counts,'o');
ylabel('Number of plant');
yyaxis right
pd = fitdist(SV,'Kernel');
xgrid = linspace(0,1)';
pdfEst = pdf(pd,xgrid);
line(xgrid,pdfEst)
ylabel('Probability density');
xlabel('Projected area of SM canopy (m2)');

% Correlation between water depth and SVF

colors = colormap(parula(5));
depthColumn = ["Sta.1_D", "Sta.2_D", "Sta.3_D", "Sta.4_D", "Sta.5_D"];
plotColumn = ["Sta.1_SVF", "Sta.2_SVF", "Sta.3_SVF", "Sta.4_SVF", "Sta.5_SVF"];
thresholdSmall = [0.68 0.62 0.55 0.69 0.61];
thresholdBig =   [0.68 0.62 0.93 0.94 0.82];
alpha = 0.5;

hold on;
for n = 1:numel(plotColumn)
    h = TAB_Hydro{:, depthColumn(n)};
    var = TAB_Hydro{:, plotColumn(n)};

    idBig = h >= thresholdBig(n);
    idSmall = TAB_Hydro{:, depthColumn(n)} < thresholdSmall(n);
    idMed = ~idBig & ~idSmall;

    plot(h(idBig),   var(idBig),   'o', 'MarkerSize', 8, 'MarkerEdgeColor', 'none', 'MarkerFaceColor', colors(n,:));
    plot(h(idSmall), var(idSmall), 'o', 'MarkerSize', 8, 'MarkerEdgeColor', colors(n,:), 'MarkerFaceColor', [1 1 1]);

    color = alpha*colors(n,:) + (1-alpha)*[1 1 1];
    plot(h(idMed), var(idMed), 'o', 'MarkerSize', 8, 'MarkerEdgeColor', 'none', 'MarkerFaceColor', color);
end





